@@ -3,6 +3,7 @@
 # @Author  : Navy
 
 class ProxyAbuyun(object):
+
     def __init__(self, username, password):
         self.username = username
         self.password = password
@@ -28,3 +29,7 @@ class ProxyAbuyun(object):
             "https": proxyMeta
         }
         return proxies
+
+
+def proxy(user, pwd):
+    return ProxyAbuyun(user, pwd).proxy
